summaryrefslogtreecommitdiff
path: root/internal/askcli/taskexec.go
diff options
context:
space:
mode:
authorPaul Buetow <paul@buetow.org>2026-04-11 22:20:57 +0300
committerPaul Buetow <paul@buetow.org>2026-04-11 22:20:57 +0300
commit69d3ec004b8de3b9f7cfeb34686b9c344c787db4 (patch)
tree857101184293efa61f9d1caba4c3b80b31e89a37 /internal/askcli/taskexec.go
parent5bc434d71fb5057131f1e5c0b2371db42d3b4ed4 (diff)
Rename task CLI binary from do back to ask
- Move cmd/do to cmd/ask; mage builds and installs ask; Fish completions to ask.fish - Update askcli help text, errors, executor default label, and Fish script (__ask_*) - Task alias cache subdirectory under XDG cache: hexai/ask/ - Rename integration test files and helpers; refresh README and docs - Rename plan-do-uuid-wrapper.md to plan-ask-uuid-wrapper.md Made-with: Cursor
Diffstat (limited to 'internal/askcli/taskexec.go')
-rw-r--r--internal/askcli/taskexec.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/internal/askcli/taskexec.go b/internal/askcli/taskexec.go
index d479c34..0b68e3b 100644
--- a/internal/askcli/taskexec.go
+++ b/internal/askcli/taskexec.go
@@ -16,7 +16,7 @@ type repoTopLevelDetector func(context.Context) (string, error)
type commandRunner func(context.Context, string, []string, io.Reader, io.Writer, io.Writer) error
// Executor encapsulates how the do CLI communicates with the Taskwarrior binary.
type Executor struct {
commandName string
findBinary binaryFinder
@@ -97,14 +97,14 @@ func (e Executor) Run(ctx context.Context, args []string, stdin io.Reader, stdou
func (e Executor) label() string {
label := strings.TrimSpace(e.commandName)
if label == "" {
- return "do"
+ return "ask"
}
return label
}
func normalizeExecutor(e Executor) Executor {
if e.commandName == "" {
- e.commandName = "do"
+ e.commandName = "ask"
}
if e.findBinary == nil {
e.findBinary = findTaskBinary
@@ -16,7 +16,7 @@ type repoTopLevelDetector func(context.Context) (string, error)
type commandRunner func(context.Context, string, []string, io.Reader, io.Writer, io.Writer) error
-// Executor encapsulates how the do CLI communicates with the Taskwarrior binary.
+// Executor encapsulates how the ask CLI communicates with the Taskwarrior binary.
type Executor struct {
commandName string